AdvertisingDataDeprecated

Struct AdvertisingDataDeprecated 

pub struct AdvertisingDataDeprecated {
    pub name: Option<String>,
    pub tx_power_level: Option<Box<Int8>>,
    pub appearance: Option<Box<UInt16>>,
    pub service_uuids: Option<Vec<String>>,
    pub service_data: Option<Vec<ServiceDataEntry>>,
    pub manufacturer_specific_data: Option<Vec<ManufacturerSpecificDataEntry>>,
    pub solicited_service_uuids: Option<Vec<String>>,
    pub uris: Option<Vec<String>>,
}
Represents advertising and scan response data advertised by a broadcaster or peripheral.

Fields

name: Option<String>

Name of the device.

tx_power_level: Option<Box<Int8>>

The radio transmission power level reported in the advertisement.

appearance: Option<Box<UInt16>>

The appearance reported in the advertisemet.

service_uuids: Option<Vec<String>>

List of service UUIDs reported in the advertisement.

service_data: Option<Vec<ServiceDataEntry>>

Service data included in the advertisement.

manufacturer_specific_data: Option<Vec<ManufacturerSpecificDataEntry>>

Manufacturer specific data entries.

solicited_service_uuids: Option<Vec<String>>

Service UUIDs that were solicited in the advertisement. Peripherals can invite centrals that expose certain services to connect to them using service solicitation.

uris: Option<Vec<String>>

URIs included in the advertising packet. These are full URIs (they are encoded/decoded automatically)